@@ -56,6 +56,8 @@ def start_lambda(model, lval: str, rval: str):
     while first not in obs:
         try:
             first = model.first_manifs[first]
+            if first == rval:
+                return 0.0
         except KeyError:
             return 0.0
     if first is None or not hasattr(model, 'mx_data'):
@@ -206,7 +208,7 @@ def start_d(model, lval: str, rval: str):
         Starting value.
 
     """
-    return 1.0
+    return 0.05
 
 def start_v(model, lval: str, rval: str):
     """
